simplify.CardToken

Package simplify :: Class CardToken |
[hide private]
[frames] | no frames]

# Class CardToken

source code

    domain.Domain --+
                    |
                   CardToken

A CardToken object.

Instance Methods | [hide private]
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an CardToken object | source code
find(object_id, *auth_args) Retrieve a CardToken object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an CardToken object Parameters: `params` - a dict of parameters; valid keys are: `authenticatePayer`: Set as true to create CardToken for EMV 3DS transaction. [default: false] `callback`: The URL callback for the cardtoken `card => addressCity`: City of the cardholder. [max length: 50, min length: 2] `card => addressCountry`: Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] `card => addressLine1`: Address of the cardholder. [max length: 255] `card => addressLine2`: Address of the cardholder if needed. [max length: 255] `card => addressState`: State of residence of the cardholder. State abbreviations should be used. [max length: 255] `card => addressZip`: Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. [max length: 32] `card => cvc`: CVC security code of the card. This is the code on the back of the card. Example: 123 `card => expMonth`: Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] `card => expYear`: Expiration year of the card. Format is YY. Example: 2013 = 13 [min value: 0, max value: 99] `card => name`: Name as appears on the card. [max length: 50, min length: 2] `card => number`: Card number as it appears on the card. [max length: 19, min length: 13] `key`: Key used to create the card token. `secure3DRequestData => amount`: Amount of the subsequent transaction in the smallest unit of your currency. Example: 100 = $1.00 required `secure3DRequestData => authOnly`: Specifies if the subsequent transaction is going to be a Payment or an Authorization (to be Captured later). If false or not specified, it refers to a Payment, otherwise it refers to an Authorization. `secure3DRequestData => currency`: Currency code (ISO-4217). Must match the currency associated with your account. required `secure3DRequestData => description`: A description of the transaction. [max length: 256] `secure3DRequestData => id`: 3D Secure data ID. `source`: Card Token Source [default: API] `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a CardToken object

### find(object_id, *auth_args) Static Method | source code
Retrieve a CardToken object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a CardToken object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `device => browser` The User-Agent header of the browser the customer used to place the order (required) `device => ipAddress` The IP address of the device used by the payer, in nnn.nnn.nnn.nnn format. (required) `device => language` The language supported for the payer's browser as defined in IETF BCP47. `device => screenHeight` The total height of the payer's browser screen in pixels. `device => screenWidth` The total width of the payer's browser screen in pixels. `device => timeZone` The timezone of the device used by the payer, in Zone ID format. Example: "Europe/Dublin" (required) `key` The public key of the merchant to be used for the token Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a CardToken object.